pub fn decrypt_blob(
key: &SecretKey,
object: &[u8],
) -> Result<Vec<u8>, CryptError>Expand description
Authenticates and decrypts an encrypted blob.
Errors
Returns a CryptError for malformed data, the wrong key, or tampering.
pub fn decrypt_blob(
key: &SecretKey,
object: &[u8],
) -> Result<Vec<u8>, CryptError>Authenticates and decrypts an encrypted blob.
Returns a CryptError for malformed data, the wrong key, or tampering.